<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Object</name>
    <message>
        <source>Duplicate method name</source>
        <translation>Mehrfaches Auftreten eines Methodennamens</translation>
    </message>
    <message>
        <source>Method names cannot begin with an upper case letter</source>
        <translation>Methodennamen dürfen nicht mit einem Großbuchstaben beginnen</translation>
    </message>
    <message>
        <source>Illegal method name</source>
        <translation>Ungültiger Methodenname</translation>
    </message>
    <message>
        <source>Duplicate signal name</source>
        <translation>Mehrfaches Auftreten eines Signalnamens</translation>
    </message>
    <message>
        <source>Duplicate property name</source>
        <translation>Mehrfaches Auftreten eines Eigenschaftsnamens</translation>
    </message>
    <message>
        <source>Property names cannot begin with an upper case letter</source>
        <translation>Eigenschaftsnamen dürfen nicht mit einem Großbuchstaben beginnen</translation>
    </message>
    <message>
        <source>Duplicate default property</source>
        <translation>Mehrfaches Auftreten der Vorgabe-Eigenschaft</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Mehrfache Zuweisung eines Wertes an eine Eigenschaft</translation>
    </message>
</context>
<context>
    <name>QInputMethod</name>
    <message>
        <source>InputMethod is an abstract class</source>
        <translation>InputMethod ist eine abstrakte Klasse</translation>
    </message>
</context>
<context>
    <name>QQmlAnonymousComponentResolver</name>
    <message>
        <source>Component objects cannot declare new functions.</source>
        <translation>Komponentenobjekte können keine neuen Funktionen deklarieren.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new properties.</source>
        <translation>Komponentenobjekte können keine neuen Eigenschaften deklarieren.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new signals.</source>
        <translation>Komponentenobjekte können keine neuen Signale deklarieren.</translation>
    </message>
    <message>
        <source>Cannot create empty component specification</source>
        <translation>Es kann keine leere Komponentenangabe erzeugt werden</translation>
    </message>
    <message>
        <source>Component elements may not contain properties other than id</source>
        <translation>Komponenten dürfen außer id keine weiteren Eigenschaften enthalten</translation>
    </message>
    <message>
        <source>Invalid component body specification</source>
        <translation>Ungültige Spezifikation des Komponentenkörpers</translation>
    </message>
    <message>
        <source>id is not unique</source>
        <translation>Id-Wert nicht eindeutig</translation>
    </message>
    <message>
        <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
        <translation>Ungültige Referenzierung einer Alias-Eigenschaft. Der Id-Wert &quot;%1&quot; konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Invalid alias target location: %1</source>
        <translation>Ungültige Zielangabe bei Alias-Eigenschaft: %1</translation>
    </message>
</context>
<context>
    <name>QQmlCodeGenerator</name>
    <message>
        <source>Signal names cannot begin with an upper case letter</source>
        <translation>Signalnamen dürfen nicht mit einem Großbuchstaben beginnen</translation>
    </message>
    <message>
        <source>Illegal signal name</source>
        <translation>Ungültiger Name für Signal</translation>
    </message>
    <message>
        <source>No property alias location</source>
        <translation>Alias-Eigenschaft ohne Quellangabe</translation>
    </message>
    <message>
        <source>Invalid alias location</source>
        <translation>Ungültige Quellangabe bei Alias-Eigenschaft</translation>
    </message>
    <message>
        <source>Invalid alias reference. An alias reference must be specified as &lt;id&gt;, &lt;id&gt;.&lt;property&gt; or &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</source>
        <translation>Ungültige Alias-Referenz. Eine Alias-Referenz muss in der Form &lt;id&gt;, &lt;id&gt;.&lt;property&gt; oder &lt;id&gt;.&lt;value property&gt;.&lt;property&gt; angegeben werden</translation>
    </message>
    <message>
        <source>Invalid component id specification</source>
        <translation>Id-Wert der Komponente ungültig</translation>
    </message>
    <message>
        <source>Invalid empty ID</source>
        <translation>Ungültiger (leerer) Id-Wert</translation>
    </message>
    <message>
        <source>IDs cannot start with an uppercase letter</source>
        <translation>Id-Werte dürfen nicht mit einem Großbuchstaben beginnen</translation>
    </message>
    <message>
        <source>IDs must start with a letter or underscore</source>
        <translation>Id-Werte müssen mit einem Buchstaben oder Unterstrich beginnen</translation>
    </message>
    <message>
        <source>IDs must contain only letters, numbers, and underscores</source>
        <translation>Id-Werte dürfen nur Ziffern, Buchstaben oder Unterstriche enthalten</translation>
    </message>
    <message>
        <source>ID illegally masks global JavaScript property</source>
        <translation>Der Id-Wert überdeckt eine globale Eigenschaft aus JavaScript</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Mehrfache Zuweisung eines Wertes an eine Eigenschaft</translation>
    </message>
    <message>
        <source>Invalid use of id property</source>
        <translation>Ungültige Verwendung der Eigenschaft &apos;id&apos;</translation>
    </message>
    <message>
        <source>Illegal property name</source>
        <translation>Ungültiger Name der Eigenschaft</translation>
    </message>
    <message>
        <source>Expected type name</source>
        <translation>Es wird ein Typname erwartet</translation>
    </message>
</context>
<context>
    <name>QQmlComponent</name>
    <message>
        <source>Invalid empty URL</source>
        <translation>Ungültige leere URL</translation>
    </message>
    <message>
        <source>createObject: value is not an object</source>
        <translation>createObject: Der Wert ist kein Objekt</translation>
    </message>
    <message>
        <source>Object destroyed during incubation</source>
        <translation>Ein Objekt wurde während der Inkubation zerstört</translation>
    </message>
</context>
<context>
    <name>QQmlConnections</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Es kann keine Zuweisung erfolgen, da keine Eigenschaft des Namens &quot;%1&quot; existiert</translation>
    </message>
    <message>
        <source>Connections: nested objects not allowed</source>
        <translation>Verbindungen: Verschachtelte Objekte sind nicht zulässig</translation>
    </message>
    <message>
        <source>Connections: syntax error</source>
        <translation>Verbindungen: Syntaxfehler</translation>
    </message>
    <message>
        <source>Connections: script expected</source>
        <translation>Verbindungen: Skript erwartet</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModel</name>
    <message>
        <source>The delegate of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>Der Delegate eines DelegateModel kann nicht in onUpdated geändert werden.</translation>
    </message>
    <message>
        <source>The maximum number of supported DelegateModelGroups is 8</source>
        <translation>Die Maximalzahl der unterstützten DelegateModelGroups ist 8</translation>
    </message>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Die Gruppe eines DelegateModel kann nicht in onChanged geändert werden</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModelGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation>Gruppennamen müssen mit einem Kleinbuchstaben beginnen</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation>get: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation>insert: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation>create: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation>resolve: Der Index &apos;from&apos; ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation>resolve: Der Index &apos;from&apos; ist ungültig</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation>resolve: Der Index &apos;to&apos; ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation>resolve: Der Index &apos;to&apos; ist ungültig</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation>resolve: Der Index &apos;from&apos; ist kein nicht aufgelöstes Element</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation>resolve: &apos;to&apos; ist kein Modellelement</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation>remove: ungültiger Index</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation>remove: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation>remove: ungültige Anzahl</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation>addGroups: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation>addGroups: ungültige Anzahl</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation>removeGroups: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation>removeGroups: ungültige Anzahl</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation>setGroups: Der Index ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation>setGroups: ungültige Anzahl</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation>move: ungültiger Index &apos;from&apos;</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation>move: ungültiger Index &apos;to&apos;</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation>move: ungültige Anzahl</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation>move: Der Index &apos;from&apos; ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation>move: Der Index &apos;to&apos; ist außerhalb des gültigen Bereichs</translation>
    </message>
</context>
<context>
    <name>QQmlEngine</name>
    <message>
        <source>Locale cannot be instantiated.  Use Qt.locale()</source>
        <translation>Locale kann nicht instanziiert werden. Verwenden Sie Qt.locale()</translation>
    </message>
    <message>
        <source>There are still &quot;%1&quot; items in the process of being created at engine destruction.</source>
        <translation>Bei der Zerstörung des Engines sind noch &quot;%1&quot; Elemente in der Erstellung.</translation>
    </message>
    <message>
        <source>executeSql called outside transaction()</source>
        <translation>&apos;executeSql&apos; wurde außerhalb von &apos;transaction()&apos; aufgerufen</translation>
    </message>
    <message>
        <source>Read-only Transaction</source>
        <translation>Schreibgeschützte Transaktion</translation>
    </message>
    <message>
        <source>Version mismatch: expected %1, found %2</source>
        <translation>Die Version %2 kann nicht verwendet werden; es wird %1 benötigt</translation>
    </message>
    <message>
        <source>SQL transaction failed</source>
        <translation>Die SQL-Transaktion ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>transaction: missing callback</source>
        <translation>callback fehlt bei Transaktion</translation>
    </message>
    <message>
        <source>SQL: can&apos;t create database, offline storage is disabled.</source>
        <translation>SQL: Es kann keine Datenbank erstellt werden, offline storage ist deaktiviert.</translation>
    </message>
    <message>
        <source>SQL: database version mismatch</source>
        <translation>SQL: Die Version der Datenbank entspricht nicht der erwarteten Version</translation>
    </message>
</context>
<context>
    <name>QQmlEnumTypeResolver</name>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: &quot;%1&quot; ist eine schreibgeschützte Eigenschaft</translation>
    </message>
</context>
<context>
    <name>QQmlImportDatabase</name>
    <message>
        <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
        <translation>&quot;%1&quot; ist nicht eindeutig. Es kommt in %2 und %3 vor</translation>
    </message>
    <message>
        <source>- %1 is not a namespace</source>
        <translation>- %1 ist kein gültiger Namensraum</translation>
    </message>
    <message>
        <source>- nested namespaces not allowed</source>
        <translation>- geschachtelte Namensräume sind nicht zulässig</translation>
    </message>
    <message>
        <source>local directory</source>
        <translation>Lokales Verzeichnis</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 and in %2</source>
        <translation>ist mehrdeutig. Es kommt in %1 und in %2 vor</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 in version %2.%3 and %4.%5</source>
        <translation>ist mehrdeutig. Es kommt in %1 in den Versionen %2.%3 und %4.%5 vor</translation>
    </message>
    <message>
        <source>is instantiated recursively</source>
        <translation>wird rekursiv instanziiert</translation>
    </message>
    <message>
        <source>is not a type</source>
        <translation>ist kein Typ</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; has no metadata URI</source>
        <translation>Das statische Plugin des Moduls &quot;%1&quot; mit dem Namen &quot;%2&quot; hat keinen Metadaten-URI</translation>
    </message>
    <message>
        <source>module does not support the designer &quot;%1&quot;</source>
        <translation>Das Modul unterstützt den Designer &quot;%1&quot; nicht</translation>
    </message>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation>Das Plugin des Moduls &quot;%1&quot; kann nicht geladen werden: %2</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; cannot be loaded: %3</source>
        <translation>Das statische Plugin des Moduls &quot;%1&quot; mit dem Namen &quot;%2&quot; kann nicht geladen werden: %3</translation>
    </message>
    <message>
        <source>could not resolve all plugins for module &quot;%1&quot;</source>
        <translation>Es konnten nicht alle Plugins für das Modul &quot;%1&quot; aufgelöst werden</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation>Modul &quot;%1&quot; Plugin &quot;%2&quot; konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
        <translation>&quot;%1&quot; Version %2.%3 ist im Modul &quot;%4&quot; mehrfach definiert</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation>Modul &quot;%1&quot; Version %2.%3 ist nicht installiert</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>Modul &quot;%1&quot; ist nicht installiert</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation>Das Verzeichnis &quot;%1&quot; existiert nicht</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation>&quot;qmldir&quot; und Namensraum fehlen bei dem Import &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Module loaded for URI &apos;%1&apos; does not implement QQmlTypesExtensionInterface</source>
        <translation>Das für den URI &apos;%1&apos; geladene Modul implementiert nicht QQmlTypesExtensionInterface</translation>
    </message>
    <message>
        <source>File name case mismatch for &quot;%1&quot;</source>
        <translation>Die Groß/Kleinschreibung des Dateinamens &quot;%1&quot; stimmt nicht überein</translation>
    </message>
    <message>
        <source>Module namespace &apos;%1&apos; does not match import URI &apos;%2&apos;</source>
        <translation>Der Modul-Namensraum &apos;%1&apos; entspricht nicht dem Import-URI &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Namespace &apos;%1&apos; has already been used for type registration</source>
        <translation>Der Namensraum &apos;%1&apos; wurde bereits zur Typregistrierung verwendet</translation>
    </message>
    <message>
        <source>Module &apos;%1&apos; does not contain a module identifier directive - it cannot be protected from external registrations.</source>
        <translation>Der Modul &apos;%1&apos; enthält keine Modulbezeichner-Direktive - er kann nicht vor externen Registrierungen geschützt werden.</translation>
    </message>
</context>
<context>
    <name>QQmlListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty!</source>
        <translation>Dynamische Rollen können nicht aktiviert werden, da das Modell nicht leer ist!</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty!</source>
        <translation>Statische Rollen können nicht aktiviert werden, da das Modell nicht leer ist!</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation>Einstellung bezüglich dynamischer Rollen muss aus dem Haupt-Thread vorgenommen werden, bevor Arbeitsskripte erstellt werden</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: Die Indizes [%1 - %2] sind außerhalb des Bereichs [0 - %3]</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation>remove: Ungültige Parameterzahl</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: Der Index %1 ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation>insert: Der Wert ist kein Objekt</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: Außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation>append: Der Wert ist kein Objekt</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation>set: Der Wert ist kein Objekt</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation>set: Der Index %1 ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation>ListElement kann keine geschachtelten Elemente enthalten</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation>ListElement: Die spezielle &quot;id&quot;-Eigenschaft kann nicht verwendet werden</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation>ListElement: Es kann kein Skript für den Wert der Eigenschaft verwendet werden</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation>ListModel: Die Eigenschaft &apos;%1&apos; ist nicht definiert</translation>
    </message>
</context>
<context>
    <name>QQmlObjectCreator</name>
    <message>
        <source>Cannot assign value %1 to property %2</source>
        <translation>Der Wert %1 kann der Eigenschaft %2 nicht zugewiesen werden</translation>
    </message>
    <message>
        <source>Cannot set properties on %1 as it is null</source>
        <translation>Es können keine Eigenschaften auf %1 gesetzt werden, da es &apos;null&apos; ist</translation>
    </message>
    <message>
        <source>Cannot assign an object to signal property %1</source>
        <translation>Der Signal-Eigenschaft %1 kann kein Objekt zugewiesen werden</translation>
    </message>
    <message>
        <source>Cannot assign object type %1 with no default method</source>
        <translation>Der Objekttyp %1 kann nicht zugewiesen werden, da keine Vorgabe-Methode existiert</translation>
    </message>
    <message>
        <source>Cannot connect mismatched signal/slot %1 %vs. %2</source>
        <translation>Es kann keine Verbindung zwischen dem Signal %1 und dem Slot %2 hergestellt werden, da sie nicht zusammenpassen</translation>
    </message>
    <message>
        <source>Cannot assign object to interface property</source>
        <translation>Der Eigenschaft der Schnittstelle kann kein Objekt zugewiesen werden</translation>
    </message>
    <message>
        <source>Cannot assign object to read only list</source>
        <translation>Zuweisung eines Objekts an eine schreibgeschützte Liste nicht zulässig</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Zuweisung eines einfachen Werts (primitive) an eine Liste nicht zulässig</translation>
    </message>
    <message>
        <source>Unable to create object of type %1</source>
        <translation>Es konnte kein Objekt des Typs %1 erzeugt werden</translation>
    </message>
    <message>
        <source>Composite Singleton Type %1 is not creatable</source>
        <translation>Das Composite Singleton des Typs %1 ist nicht erzeugbar</translation>
    </message>
</context>
<context>
    <name>QQmlObjectModel</name>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: Der Index %1 ist außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: Außerhalb des gültigen Bereichs</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: Die Indizes [%1 - %2] sind außerhalb des Bereichs [0 - %3]</translation>
    </message>
</context>
<context>
    <name>QQmlParser</name>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation>Ungültige Syntax des Exponenten</translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation>Zeichenkette am Zeilenende nicht abgeschlossen</translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation>Ungültige Unicode-Escape-Sequenz</translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation>Regulärer Ausdruck nicht abgeschlossen</translation>
    </message>
    <message>
        <source>Invalid regular expression flag &apos;%0&apos;</source>
        <translation>Ungültiger Modifikator &apos;%0&apos; bei regulärem Ausdruck</translation>
    </message>
    <message>
        <source>Stray newline in string literal</source>
        <translation>Freistehendes Zeilenendezeichen in Zeichenkettenliteral</translation>
    </message>
    <message>
        <source>Illegal hexadecimal escape sequence</source>
        <translation>Ungültige hexadezimale Escape-Sequenz</translation>
    </message>
    <message>
        <source>Octal escape sequences are not allowed</source>
        <translation>Oktale Escape-Sequenzen sind nicht zulässig</translation>
    </message>
    <message>
        <source>Decimal numbers can&apos;t start with &apos;0&apos;</source>
        <translation>Dezimalzahlen können nicht mit &apos;0&apos; beginnen</translation>
    </message>
    <message>
        <source>At least one hexadecimal digit is required after &apos;0%1&apos;</source>
        <translation>Nach &apos;0%1&apos; ist mindestens eine hexadezimale Stelle erforderlich</translation>
    </message>
    <message>
        <source>Unterminated regular expression backslash sequence</source>
        <translation>Backslash-Sequenz in regulärem Ausdruck nicht abgeschlossen</translation>
    </message>
    <message>
        <source>Unterminated regular expression class</source>
        <translation>Klasse im regulären Ausdruck nicht abgeschlossen</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Syntaxfehler</translation>
    </message>
    <message>
        <source>Unexpected token `%1&apos;</source>
        <translation>Unerwartetes Element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Expected token `%1&apos;</source>
        <translation>Es wird das Element &apos;%1&apos; erwartet</translation>
    </message>
    <message>
        <source>Unexpected object definition</source>
        <translation>Objektdefinition an dieser Stelle nicht erwartet</translation>
    </message>
    <message>
        <source>Invalid import qualifier ID</source>
        <translation>Ungültige Id-Angabe bei Import</translation>
    </message>
    <message>
        <source>Reserved name &quot;Qt&quot; cannot be used as an qualifier</source>
        <translation>Der reservierte Name &quot;Qt&quot; kann nicht als Bezeichner verwendet werden</translation>
    </message>
    <message>
        <source>Script import qualifiers must be unique.</source>
        <translation>Der für den Skript-Import angegebene Qualifizierer muss eindeutig sein.</translation>
    </message>
    <message>
        <source>Script import requires a qualifier</source>
        <translation>Der Skript-Import erfordert die Angabe eines Qualifizierers.</translation>
    </message>
    <message>
        <source>Library import requires a version</source>
        <translation>Der Import einer Bibliothek erfordert eine Versionsangabe</translation>
    </message>
    <message>
        <source>Expected parameter type</source>
        <translation>Es wird eine Typangabe für den Parameter erwartet</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: </source>
        <translation>Ungültiger Typ des Signalparameters: </translation>
    </message>
    <message>
        <source>Invalid property type modifier</source>
        <translation>Ungültiger Modifikator für den Typ der Eigenschaft</translation>
    </message>
    <message>
        <source>Unexpected property type modifier</source>
        <translation>Modifikator für den Typ der Eigenschaft an dieser Stelle nicht zulässig</translation>
    </message>
    <message>
        <source>Expected property type</source>
        <translation>Typangabe für Eigenschaft erwartet</translation>
    </message>
    <message>
        <source>JavaScript declaration outside Script element</source>
        <translation>Eine JavaScript-Deklaration ist außerhalb eines Skriptelementes nicht zulässig</translation>
    </message>
    <message>
        <source>Pragma requires a valid qualifier</source>
        <translation>Das Pragma erfordert einen gültigen Qualifizierer</translation>
    </message>
    <message>
        <source>Imported file must be a script</source>
        <translation>Eine importierte Datei muss ein Skript sein</translation>
    </message>
    <message>
        <source>File import requires a qualifier</source>
        <translation>Dateiimport erfordert die Angabe eines Qualifizierers</translation>
    </message>
    <message>
        <source>Invalid import qualifier</source>
        <translation>Ungültiger Import-Qualifizierer</translation>
    </message>
    <message>
        <source>Invalid module URI</source>
        <translation>Ungültiger Modul-URI</translation>
    </message>
    <message>
        <source>Module import requires a version</source>
        <translation>Der Import eines Moduls erfordert eine Versionsangabe</translation>
    </message>
    <message>
        <source>Module import requires a qualifier</source>
        <translation>Modulimport erfordert die Angabe eines Qualifizierers</translation>
    </message>
</context>
<context>
    <name>QQmlPartsModel</name>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Die Gruppe eines DelegateModel kann nicht in onChanged geändert werden</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation>Delegate-Komponente muss vom Typ &apos;Package&apos; sein.</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyCacheCreator</name>
    <message>
        <source>Fully dynamic types cannot declare new properties.</source>
        <translation>Vollständig dynamische Typen können keine neuen Eigenschaften deklarieren.</translation>
    </message>
    <message>
        <source>Fully dynamic types cannot declare new signals.</source>
        <translation>Vollständig dynamische Typen können keine neuen Signale deklarieren.</translation>
    </message>
    <message>
        <source>Fully Dynamic types cannot declare new functions.</source>
        <translation>Vollständig dynamische Typen können keine neuen Funktionen deklarieren.</translation>
    </message>
    <message>
        <source>Non-existent attached object</source>
        <translation>Es existiert kein Bezugselement für die Eigenschaft</translation>
    </message>
    <message>
        <source>Cannot override FINAL property</source>
        <translation>Eine als FINAL ausgewiesene Eigenschaft kann nicht überschrieben werden</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: %1</source>
        <translation>Der Signalparameter hat einen ungültigen Typ: %1</translation>
    </message>
    <message>
        <source>Duplicate signal name: invalid override of property change signal or superclass signal</source>
        <translation>Bereits vorhandener Signalname: Das Überschreiben eines Signals einer Eigenschaftsänderung oder der Basisklasse ist nicht zulässig</translation>
    </message>
    <message>
        <source>Duplicate method name: invalid override of property change signal or superclass signal</source>
        <translation>Bereits vorhandener Methodenname: Das Überschreiben eines Signals einer Eigenschaftsänderung oder der Basisklasse ist nicht zulässig</translation>
    </message>
    <message>
        <source>Invalid property type</source>
        <translation>Ungültiger Typ der Eigenschaft</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyValidator</name>
    <message>
        <source>Property assignment expected</source>
        <translation>Zuweisung an Eigenschaft erwartet</translation>
    </message>
    <message>
        <source>Invalid use of namespace</source>
        <translation>Ungültige Verwendung eines Namensraums</translation>
    </message>
    <message>
        <source>Invalid attached object assignment</source>
        <translation>Ungültige Zuweisung des Bezugselements</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot; ist in %3 %4.%5 nicht verfügbar.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot; ist in dieser Version der Komponente nicht verfügbar.</translation>
    </message>
    <message>
        <source>Cannot assign a value directly to a grouped property</source>
        <translation>Bei einer Eigenschaft, die Teil einer Gruppierung ist, ist eine direkte Wertzuweisung unzulässig</translation>
    </message>
    <message>
        <source>Attached properties cannot be used here</source>
        <translation>An dieser Stelle können keine Eigenschaften des Typs &apos;attached&apos; verwendet werden</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: &quot;%1&quot; ist schreibgeschützt</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a script property</source>
        <translation>Eine Zuweisung mehrerer Werte an eine Skript-Eigenschaft ist nicht zulässig</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a singular property</source>
        <translation>Eine Zuweisung mehrerer Werte an eine einfache Eigenschaft ist nicht zulässig</translation>
    </message>
    <message>
        <source>Property has already been assigned a value</source>
        <translation>Der Eigenschaft wurde bereits ein Wert zugewiesen</translation>
    </message>
    <message>
        <source>Invalid grouped property access</source>
        <translation>Falscher Zugriff auf gruppierte Eigenschaft</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent default property</source>
        <translation>Es kann keine Zuweisung an eine nicht existierende Vorgabe-Eigenschaft erfolgen</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Es kann keine Zuweisung erfolgen, da keine Eigenschaft des Namens &quot;%1&quot; existiert</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Zuweisung eines einfachen Werts (primitive) an eine Liste nicht zulässig</translation>
    </message>
    <message>
        <source>Invalid property assignment: unknown enumeration</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Unbekannter Aufzählungswert</translation>
    </message>
    <message>
        <source>Invalid property assignment: string expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zeichenkette erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or string list expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zeichenkette oder eine Liste von Zeichenketten erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: byte array expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein Bytefeld erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: url expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine URL erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsigned int expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein vorzeichenloser Ganzzahlwert erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: int expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein Ganzzahlwert erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: number expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zahl erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: color expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Farbspezifikation erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: date expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Datumsangabe erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: time expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zeitangabe erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: datetime expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein Zeitstempel erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: point expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Koordinatenangabe für einen Punkt erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: size expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Größenangabe erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: rect expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es werden Parameter für ein Rechteck erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: boolean expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein boolescher Wert erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: 3D vector expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein dreidimensionaler Vektor erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: 4D vector expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein vierdimensionaler Vektor erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein regulärer Ausdruck erwartet; verwenden Sie die Schreibweise /Muster/</translation>
    </message>
    <message>
        <source>Invalid property assignment: number or array of numbers expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zahl oder ein Feld von Zahlen erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: int or array of ints expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein Ganzahlwert oder ein Feld ganzer Zahlen erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: bool or array of bools expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird boolescher Wert oder ein Feld boolescher Werten erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: url or array of urls expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine URL oder ein Feld von URLs erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or array of strings expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Zeichenkette oder ein Feld von Zeichenketten erwartet</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsupported type &quot;%1&quot;</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Der Typ &quot;%1&quot; wird nicht unterstützt</translation>
    </message>
    <message>
        <source>&quot;%1&quot; cannot operate on &quot;%2&quot;</source>
        <translation>&quot;%1&quot; kann nicht auf  &quot;%2&quot; angewandt werden</translation>
    </message>
    <message>
        <source>Cannot assign object to list property &quot;%1&quot;</source>
        <translation>Der Listeneigenschaft &quot;%1&quot; kann kein Objekt zugewiesen werden</translation>
    </message>
    <message>
        <source>Unexpected object assignment</source>
        <translation>Unerwartete Zuweisung des Objekts</translation>
    </message>
    <message>
        <source>Invalid property assignment: script expected</source>
        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein Skript erwartet</translation>
    </message>
    <message>
        <source>Cannot assign object to property</source>
        <translation>Zuweisung eines Objekts an eine Eigenschaft nicht zulässig</translation>
    </message>
</context>
<context>
    <name>QQmlRewrite</name>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Das Signal verwendet einen namenlosen Parameter gefolgt von einem Parameter mit Namen</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Der Signalparameter &quot;%1&quot; überdeckt eine globale Variable.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeCompiler</name>
    <message>
        <source>Composite Singleton Type %1 is not creatable.</source>
        <translation>Es kann kein Composite Singleton des Typs %1 erzeugt werden.</translation>
    </message>
    <message>
        <source>Element is not creatable.</source>
        <translation>Das Element kann nicht erzeugt werden.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeLoader</name>
    <message>
        <source>Cannot update qmldir content for &apos;%1&apos;</source>
        <translation>Der Inhalt von qmldir für &apos;%1&apos; kann nicht auf den aktuellen Stand gebracht werden</translation>
    </message>
    <message>
        <source>No matching type found, pragma Singleton files cannot be used by QQmlComponent.</source>
        <translation>Es konnte kein passender Typ gefunden werden; Dateien, die pragma Singleton enthalten, können von QQmlComponent nicht verwendet werden.</translation>
    </message>
    <message>
        <source>pragma Singleton used with a non composite singleton type %1</source>
        <translation>pragma Singleton in Zusammenhang mit Nicht-Composite Singleton des Typs %1 verwendet</translation>
    </message>
    <message>
        <source>Script %1 unavailable</source>
        <translation>Das Skript %1 ist nicht verfügbar</translation>
    </message>
    <message>
        <source>Type %1 unavailable</source>
        <translation>Der Typ %1 ist nicht verfügbar</translation>
    </message>
    <message>
        <source>qmldir defines type as singleton, but no pragma Singleton found in type %1.</source>
        <translation>qmldir definiert den Typ als Singleton, aber der Typ %1 enthält kein pragma Singleton.</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>Modul &quot;%1&quot; ist nicht installiert</translation>
    </message>
    <message>
        <source>Namespace %1 cannot be used as a type</source>
        <translation>Der Namensraum %1 kann nicht als Typangabe verwendet werden</translation>
    </message>
    <message>
        <source>Unreported error adding script import to import database</source>
        <translation>Nicht gemeldeter Fehler beim Hinzufügen eines Skriptes zu einer Importdatenbank</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>QQuickAbstractAnimation</name>
    <message>
        <source>Cannot animate non-existent property &quot;%1&quot;</source>
        <translation>Die Eigenschaft &quot;%1&quot; existiert nicht und kann daher nicht animiert werden</translation>
    </message>
    <message>
        <source>Cannot animate read-only property &quot;%1&quot;</source>
        <translation>Die Eigenschaft &quot;%1&quot; ist schreibgeschützt und kann daher nicht animiert werden</translation>
    </message>
    <message>
        <source>Animation is an abstract class</source>
        <translation>Die Klasse Animation ist abstrakt</translation>
    </message>
    <message>
        <source>Animator is an abstract class</source>
        <translation>Die Klasse Animator ist abstrakt</translation>
    </message>
</context>
<context>
    <name>QQuickAccessibleAttached</name>
    <message>
        <source>Accessible is only available via attached properties</source>
        <translation>Auf Accessible kann nur mittels Eigenschaften des Typs&apos;attached&apos; zugegriffen werden</translation>
    </message>
</context>
<context>
    <name>QQuickAnchorAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Es kann keine Zeitdauer &lt;0 gesetzt werden</translation>
    </message>
</context>
<context>
    <name>QQuickAnchors</name>
    <message>
        <source>Possible anchor loop detected on fill.</source>
        <translation>Bei der Fülloperation wurde eine potentielle Endlosschleife der Anker festgestellt.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on centerIn.</source>
        <translation>Bei der Operation &apos;centerIn&apos; wurde eine potentielle Endlosschleife der Anker festgestellt.</translation>
    </message>
    <message>
        <source>Cannot anchor to an item that isn&apos;t a parent or sibling.</source>
        <translation>Das Ziel eines Anker muss ein Elternelement oder Element der gleichen Ebene sein.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on vertical anchor.</source>
        <translation>Bei einem vertikalen Anker wurde eine potentielle Endlosschleife der Anker festgestellt.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on horizontal anchor.</source>
        <translation>Bei einem horizontalen Anker wurde eine potentielle Endlosschleife der Anker festgestellt.</translation>
    </message>
    <message>
        <source>Cannot specify left, right, and horizontalCenter anchors at the same time.</source>
        <translation>Ankerangaben für links, rechts und horizontal können nicht zusammen festgelegt werden.</translation>
    </message>
    <message>
        <source>Cannot anchor to a null item.</source>
        <translation>Es kann kein Anker zu einem Null-Element angegeben werden.</translation>
    </message>
    <message>
        <source>Cannot anchor a horizontal edge to a vertical edge.</source>
        <translation>Eine horizontale Kante kann nicht mit einer vertikalen Kante verankert werden.</translation>
    </message>
    <message>
        <source>Cannot anchor item to self.</source>
        <translation>Ein Element kann keinen Anker zu sich selbst haben.</translation>
    </message>
    <message>
        <source>Cannot specify top, bottom, and verticalCenter anchors at the same time.</source>
        <translation>Ankerangaben für oben, unten und vertikal können nicht zusammen festgelegt werden.</translation>
    </message>
    <message>
        <source>Baseline anchor cannot be used in conjunction with top, bottom, or verticalCenter anchors.</source>
        <translation>Ein Baseline-Anker kann nicht zusammen mit oberen, unteren oder vertikal zentrierten Ankern verwendet werden.</translation>
    </message>
    <message>
        <source>Cannot anchor a vertical edge to a horizontal edge.</source>
        <translation>Vertikale und horizontale Kanten können nicht mit Ankern verbunden werden.</translation>
    </message>
</context>
<context>
    <name>QQuickAnimatedImage</name>
    <message>
        <source>Qt was built without support for QMovie</source>
        <translation>Diese Version der Qt-Bibliothek wurde ohne Unterstützung für die Klasse QMovie erstellt</translation>
    </message>
</context>
<context>
    <name>QQuickApplication</name>
    <message>
        <source>Application is an abstract class</source>
        <translation>&apos;Application&apos; ist eine abstrakte Klasse</translation>
    </message>
</context>
<context>
    <name>QQuickBehavior</name>
    <message>
        <source>Cannot change the animation assigned to a Behavior.</source>
        <translation>Die zu einem Behavior-Element gehörende Animation kann nicht geändert werden.</translation>
    </message>
</context>
<context>
    <name>QQuickDragAttached</name>
    <message>
        <source>Drag is only available via attached properties</source>
        <translation>Auf Drag kann nur mittels Eigenschaften des Typs &apos;attached&apos; zugegriffen werden</translation>
    </message>
</context>
<context>
    <name>QQuickEnterKeyAttached</name>
    <message>
        <source>EnterKey attached property only works with Items</source>
        <translation>Die EnterKey-Eigenschaft des Typs &apos;attached&apos; kann nur mit Elementen der Klasse Item verwendet werden</translation>
    </message>
    <message>
        <source>EnterKey is only available via attached properties</source>
        <translation>Auf EnterKey kann nur mittels Eigenschaften des Typs &apos;attached&apos; zugegriffen werden</translation>
    </message>
</context>
<context>
    <name>QQuickFlipable</name>
    <message>
        <source>front is a write-once property</source>
        <translation>&apos;front&apos; kann nur einmal zugewiesen werden</translation>
    </message>
    <message>
        <source>back is a write-once property</source>
        <translation>&apos;back&apos; kann nur einmal zugewiesen werden</translation>
    </message>
</context>
<context>
    <name>QQuickItemView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate-Komponente muss vom Typ &apos;Item&apos; sein</translation>
    </message>
    <message>
        <source>ItemView is an abstract base class</source>
        <translation>ItemView ist eine abstrakte Basisklasse</translation>
    </message>
</context>
<context>
    <name>QQuickKeyNavigationAttached</name>
    <message>
        <source>KeyNavigation is only available via attached properties</source>
        <translation>Tastennavigation ist nur über Eigenschaften des Typs &apos;attached&apos; verfügbar</translation>
    </message>
</context>
<context>
    <name>QQuickKeysAttached</name>
    <message>
        <source>Keys is only available via attached properties</source>
        <translation>Die Unterstützung für Tasten ist nur über Eigenschaften des Typs &apos;attached&apos; verfügbar</translation>
    </message>
</context>
<context>
    <name>QQuickLayoutMirroringAttached</name>
    <message>
        <source>LayoutDirection attached property only works with Items</source>
        <translation>LayoutDirection-Eigenschaften des Typs &apos;attached&apos; können nur mit Elementen der Klasse Item verwendet werden</translation>
    </message>
    <message>
        <source>LayoutMirroring is only available via attached properties</source>
        <translation>LayoutMirroring ist nur in Verbindung mit Eigenschaften des Typs &quot;attached&quot; möglich</translation>
    </message>
</context>
<context>
    <name>QQuickLoader</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation>setSource: Der Wert ist kein Objekt</translation>
    </message>
</context>
<context>
    <name>QQuickOpenGLInfo</name>
    <message>
        <source>OpenGLInfo is only available via attached properties</source>
        <translation>Auf OpenGLInfo kann nur mittels Eigenschaften des Typs &apos;attached&apos; zugegriffen werden</translation>
    </message>
</context>
<context>
    <name>QQuickPaintedItem</name>
    <message>
        <source>Cannot create instance of abstract class PaintedItem</source>
        <translation>Es kann keine Instanz der abstrakten Klasse PaintedItem erstellt werden</translation>
    </message>
</context>
<context>
    <name>QQuickParentAnimation</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Das Erscheinungsbild kann bei einer komplexen Transformation nicht beibehalten werden</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Das Erscheinungsbild kann bei einer nicht-uniformen Skalierung nicht beibehalten werden</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Das Erscheinungsbild kann bei einer Skalierung mit 0 nicht beibehalten werden</translation>
    </message>
</context>
<context>
    <name>QQuickParentChange</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Das Erscheinungsbild kann bei einer komplexen Transformation nicht beibehalten werden</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Das Erscheinungsbild kann bei einer nicht-uniformen Skalierung nicht beibehalten werden</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Das Erscheinungsbild kann bei einer Skalierung mit 0 nicht beibehalten werden</translation>
    </message>
</context>
<context>
    <name>QQuickPathAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Es kann keine Zeitdauer &lt;0 gesetzt werden</translation>
    </message>
</context>
<context>
    <name>QQuickPathView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate-Komponente muss vom Typ &apos;Item&apos; sein</translation>
    </message>
</context>
<context>
    <name>QQuickPauseAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Es kann keine Zeitdauer &lt;0 gesetzt werden</translation>
    </message>
</context>
<context>
    <name>QQuickPixmap</name>
    <message>
        <source>Error decoding: %1: %2</source>
        <translation>Fehler beim Dekodieren: %1: %2</translation>
    </message>
    <message>
        <source>Invalid image provider: %1</source>
        <translation>Ungültige Bildquelle: %1</translation>
    </message>
    <message>
        <source>Failed to get image from provider: %1</source>
        <translation>Bilddaten konnten nicht erhalten werden: %1</translation>
    </message>
    <message>
        <source>Failed to get texture from provider: %1</source>
        <translation>Es konnte keine Textur vom Provider %1 erhalten werden</translation>
    </message>
    <message>
        <source>Cannot open: %1</source>
        <translation>Fehlschlag beim Öffnen: %1</translation>
    </message>
    <message>
        <source>Invalid image data: %1</source>
        <translation>Ungültige Bilddaten: %1</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Es kann keine Zeitdauer &lt;0 gesetzt werden</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyChanges</name>
    <message>
        <source>PropertyChanges does not support creating state-specific objects.</source>
        <translation>Die Erzeugung von Objekten, die einem Zustand zugeordnet sind, wird von PropertyChanges nicht unterstützt.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Es kann keine Zuweisung erfolgen, da keine Eigenschaft des Namens &apos;%1&quot; existiert</translation>
    </message>
    <message>
        <source>Cannot assign to read-only property &quot;%1&quot;</source>
        <translation>Die Eigenschaft &quot;%1&quot; ist schreibgeschützt und kann daher nicht zugewiesen werden</translation>
    </message>
</context>
<context>
    <name>QQuickRepeater</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate-Komponente muss vom Typ &apos;Item&apos; sein</translation>
    </message>
</context>
<context>
    <name>QQuickShaderEffectMesh</name>
    <message>
        <source>Cannot create instance of abstract class ShaderEffectMesh.</source>
        <translation>Es kann keine Instanz der abstrakten Klasse ShaderEffectMesh erstellt werden.</translation>
    </message>
</context>
<context>
    <name>QQuickTextUtil</name>
    <message>
        <source>%1 does not support loading non-visual cursor delegates.</source>
        <translation>%1 unterstützt nicht das Laden von nicht visuellen Cursor-Delegates.</translation>
    </message>
    <message>
        <source>Could not load cursor delegate</source>
        <translation>Cursor-Delegate konnte nicht geladen werden</translation>
    </message>
</context>
<context>
    <name>QQuickViewTransitionAttached</name>
    <message>
        <source>ViewTransition is only available via attached properties</source>
        <translation>ViewTransition ist nur über Eigenschaften des Typs &apos;attached&apos; verfügbar</translation>
    </message>
</context>
<context>
    <name>QQuickWindow</name>
    <message>
        <source>Failed to create %1 context for format %2.
This is most likely caused by not having the necessary graphics drivers installed.

Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, make sure the ANGLE Open GL ES 2.0 emulation libraries (%3, %4 and d3dcompiler_*.dll) are available in the application executable&apos;s directory or in a location listed in PATH.</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format, ANGLE %3, %4 library names</extracomment>
        <translation>Es konnte kein %1-Kontext für das Format %2 erzeugt werden.
Die wahrscheinliche Ursache ist, dass die erforderlichen Grafiktreiber nicht installiert sind.

Installieren Sie einen Treiber, der OpenGL 2.0 oder neuer bereitstellt, oder stellen Sie sicher, dass die ANGLE-Open GL ES 2.0-Emulationsbibliotheken (%3, %4 und d3dcompiler_*.dll) im Verzeichnis der ausführbaren Datei der Anwendung oder im Pfad verfügbar sind.</translation>
    </message>
    <message>
        <source>Failed to create %1 context for format %2</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format specification</extracomment>
        <translation>Es konnte kein %1-Kontext für das Format %2 erzeugt werden</translation>
    </message>
</context>
<context>
    <name>QQuickWindowQmlImpl</name>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos; for Window &apos;%1&apos;</source>
        <translation>Widersprüchliche Eigenschaften &apos;visible&apos; und &apos;visibility&apos; für das Fenster &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos;</source>
        <translation>Widersprüchliche Eigenschaften &apos;visible&apos; und &apos;visibility&apos;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModel</name>
    <message>
        <source>&quot;%1&quot; duplicates a previous role name and will be disabled.</source>
        <translation>&quot;%1&quot; ist bereits als Name einer Rolle vergeben und wird daher deaktiviert.</translation>
    </message>
    <message>
        <source>invalid query: &quot;%1&quot;</source>
        <translation>Ungültige Abfrage: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModelRole</name>
    <message>
        <source>An XmlRole query must not start with &apos;/&apos;</source>
        <translation>Eine XmlRole-Abfrage darf nicht mit &apos;/&apos; beginnen</translation>
    </message>
</context>
<context>
    <name>QQuickXmlRoleList</name>
    <message>
        <source>An XmlListModel query must start with &apos;/&apos; or &quot;//&quot;</source>
        <translation>Eine XmlListModel-Abfrage muss mit &apos;/&apos; oder &quot;//&quot; beginnen</translation>
    </message>
</context>
<context>
    <name>SignalHandlerConverter</name>
    <message>
        <source>Non-existent attached object</source>
        <translation>Das als &quot;attached&quot; angegebene Objekt existiert nicht</translation>
    </message>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Das Signal verwendet einen unbenannten Parameter, auf den ein benannter Parameter folgt.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Der Signalparameter &quot;%1&quot; überdeckt eine globale Variable.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot; ist in %3 %4.%5 nicht verfügbar.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot; ist wegen der Versionierung der Komponente nicht verfügbar.</translation>
    </message>
    <message>
        <source>Cannot assign a value to a signal (expecting a script to be run)</source>
        <translation>Einem Signal können keine Werte zugewiesen werden (es wird ein ausführbares Skript erwartet)</translation>
    </message>
    <message>
        <source>Incorrectly specified signal assignment</source>
        <translation>Angegebene Signalzuweisung ist nicht korrekt</translation>
    </message>
</context>
<context>
    <name>qmlRegisterType</name>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;</source>
        <translation>Ungültiger QML %1-Name: &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into unregistered namespace &apos;%3&apos;</source>
        <translation>%1 &apos;%2&apos; kann nicht in einen nicht registrierten Namensraum &apos;%3&apos; installiert werden</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected namespace &apos;%3&apos;</source>
        <translation>%1 &apos;%2&apos; kann nicht in einen geschützten Namensraum &apos;%3&apos; installiert werden</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected module &apos;%3&apos; version &apos;%4&apos;</source>
        <translation>%1 &apos;%2&apos; kann nicht in das geschützte Modul &apos;%3&apos; der Version &apos;%4&apos; installiert werden</translation>
    </message>
</context>
</TS>
